/*****************************************************************************
 * Copyright 2012 celum Slovakia s r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *****************************************************************************/
package com.celum.dbtool.resource;

import com.celum.dbtool.script.*;
import org.apache.commons.io.IOUtils;

import java.io.IOException;
import java.io.InputStream;
import java.util.Collection;
import java.util.Collections;
import java.util.LinkedList;
import java.util.List;

/**
 * provides access to SQL scripts on classpath.
 *
 * @author Zdenko Vrabel (zdenko.vrabel@celum.com)
 */
public class ClasspathResource extends DbScriptsResource
{
    /** array of paths to scripts on classloader */
	private final String[] paths;

    /** classloader which is used */
	private final ClassLoader classLoader;


	/**
	 * Constructor
	 * @param paths
	 */
	public ClasspathResource(String... paths)
	{
		this(ClasspathResource.class.getClassLoader(), paths);
	}


	/**
	 * Constructor
	 *
	 * @param classLoader
	 * @param paths
	 */
	public ClasspathResource(ClassLoader classLoader, String... paths)
	{
		this.paths = paths;
		this.classLoader = classLoader;
	}


	/**
	 * read all resources from classpath and returns sql scripts as a
	 * sorted collection
	 * @return
	 */
	@Override
	public Collection<DbScript> getSortedScripts(VersionFactory vf)
	{
		try {
			List<DbScript> sqlScripts = new LinkedList<DbScript>();
			for (int i = 0; i < paths.length; ++i) {
				InputStream is = classLoader.getResourceAsStream(paths[i]);
				String script = IOUtils.toString(is);
                Version v = vf.parse(paths[i]);
                ScriptType type = ScriptType.getTypeOfFile(paths[i]);
                if (type != ScriptType.UNSUPPORTED) {
				    sqlScripts.add(new StringScript(paths[i], v, type, script));
                }
			}

			Collections.sort(sqlScripts);
			return sqlScripts;
		} catch (IOException e) {
			throw new IllegalStateException(e);
		}
	}
}
