/*****************************************************************************
 * Copyright 2012 celum Slovakia s r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *****************************************************************************/
package com.celum.dbtool.resource;

import com.celum.dbtool.script.*;

import java.io.File;
import java.util.Collection;
import java.util.Collections;
import java.util.LinkedList;
import java.util.List;

/**
 * Implementation of {@link DbScriptsResource resource} which loads scripts
 * from given directory.
 *
 * @author Zdenko Vrabel (zdenko.vrabel@celum.com)
 */
public class DirResource extends DbScriptsResource
{
	/** points to directory where are SQL scripts */
	private final File dir;


	/**
	 * Constructor
	 * @param dir
	 */
	public DirResource(File dir)
	{
		this.dir = dir;
	}


	/**
	 * reads all script files inside directory, sort them and return
	 * them as a collection of sql scripts
	 * @return
	 */
	@Override
	public Collection<DbScript> getSortedScripts(VersionFactory vf)
	{
		if (dir == null) {
			throw new IllegalStateException("Configuration error. Please define a scripts-directory for that goal in your pom.xml");
		}

		File[] scripts = dir.listFiles();
		if (scripts == null) {
			throw new IllegalStateException("non-existing or empty folder " + dir.toString());
		}

		List<DbScript> out = new LinkedList<DbScript>();
		for (int i = 0; i < scripts.length; ++i) {
			if (scripts[i].isFile()) {
                Version v = vf.parse(scripts[i].getName());
                ScriptType type = ScriptType.getTypeOfFile(scripts[i].getName());
                if (type != ScriptType.UNSUPPORTED) {
				    DbScript script = new FileScript(scripts[i], v, type);
				    out.add(script);
                }
			}
		}

		Collections.sort(out);
		return out;
	}
}
