/*****************************************************************************
 * Copyright 2012 celum Slovakia s r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *****************************************************************************/
package com.celum.dbtool.script;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * Factory for {@link LongVersion}
 *
 * @author Zdenko Vrabel (zdenko.vrabel@celum.com)
 */
public class LongVersionFactory implements VersionFactory {

    private static final Pattern LONG_PATTERN = Pattern.compile("(\\d+).*");

    /**
     * {@inheritDoc}
     */
    @Override
    public Version parse(String text)
    {
        Matcher m = LONG_PATTERN.matcher(text);
        if (!m.find()) {
            //throw new DbException("cannot convert " + text + " to long version");
            return new LongVersion(0);
        }

        long versionId = Long.parseLong(m.group(1));
        return new LongVersion(versionId);
    }
}
