/*****************************************************************************
 * Copyright 2012 celum Slovakia s r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *****************************************************************************/
package com.celum.dbtool.script;

/**
 * Supported script types. The type determines how script will
 * be executed in {@link DbInstaller installer}
 *
 * @author Zdenko Vrabel (zdenko.vrabel@celum.com)
 */
public enum ScriptType {

    UNSUPPORTED,
    SQL,
    GROOVY;

    /**
     * Method returns file's type based on file's extension.
     * When file ends with '.sql' the type is SQL. The '.groovy' means
     * GROOVY type. All other extensions are translated as 'UNSUPPORTED'.
     *
     * @param pathToFile
     * @return
     */
    public static final ScriptType getTypeOfFile(String pathToFile)
    {
        if (pathToFile.endsWith(".sql")) {
            return SQL;
        } else if (pathToFile.endsWith(".groovy")) {
            return GROOVY;
        }
        return UNSUPPORTED;
    }
}
