/*****************************************************************************
 * Copyright 2012 celum Slovakia s r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *****************************************************************************/
package com.celum.dbtool.sql;

import java.util.logging.Logger;

/**
 * @author Zdenko Vrabel (zdenko.vrabel@celum.com)
 */
public class LogDecorator<T extends SqlScriptStrategy> extends DecoratorScriptStrategy<T>
{
    /** logger */
    private static Logger LOG = Logger.getLogger(LogDecorator.class.getName());

    /**
     * Use this factory method instead of constructor.
     *
     * @param decoratedStrategy
     */
    public static <T extends SqlScriptStrategy> LogDecorator<T> decorate(T decoratedStrategy)
    {
        return new LogDecorator<T>(decoratedStrategy);
    }


    /**
     * Constructor
     *
     * @param decoratedStrategy
     */
    private LogDecorator(T decoratedStrategy) {
        super(decoratedStrategy);
    }


    /**
     * {@inheritDoc}
     * @param sql
     */
    @Override
    public void query(String sql)
    {
        try {
            LOG.info("[SQL]:" + sql);
            fromDecoratedStrategy().query(sql);
            LOG.fine("[SQL OK]:" + sql);
        } catch (RuntimeException e) {
            LOG.severe("[SQL ERROR]:" + sql + " msg:" + e.getMessage());
            throw e;
        }
    }
}
