/*****************************************************************************
 * Copyright 2012 celum Slovakia s r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *****************************************************************************/
package com.celum.dbtool.sql;

import org.antlr.v4.runtime.tree.TerminalNode;

/**
 * @author Zdenko Vrabel (zdenko.vrabel@celum.com)
 */
class ParserGrammarListener extends AbstractSqlGrammarListener {

    private final SqlScriptStrategy strategy;
    private String actualScript = "";
    private boolean isScript = false;

    /**
     * Constructor
     * @param strategy
     */
    ParserGrammarListener(SqlScriptStrategy strategy)
    {
        this.strategy = strategy;
    }

    @Override
    public void exitSqlCommand(SqlGrammarParser.SqlCommandContext ctx)
    {
        if (!isScript) {
            finishScript();
        }
    }

    @Override
    public void exitEndScript(SqlGrammarParser.EndScriptContext ctx)
    {
        finishScript();
    }

    @Override
    public void enterBeginScript(SqlGrammarParser.BeginScriptContext ctx)
    {
        isScript = true;
    }

    @Override
    public void visitTerminal(TerminalNode terminalNode)
    {
        String txt = terminalNode.getSymbol().getText();
        if (txt == null) {
            return;
        }
        actualScript = actualScript + " " +terminalNode.getSymbol().getText();
    }

    protected void finishScript()
    {
        strategy.query(actualScript);
        actualScript = "";
        isScript = false;
    }
}
