/*****************************************************************************
 * Copyright 2012 celum Slovakia s r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *****************************************************************************/
package com.celum.dbtool.sql;

import org.apache.commons.dbutils.DbUtils;

import java.sql.Connection;
import java.sql.SQLException;
import java.sql.Statement;

/**
 * Executes SQL query on DB via concrete connection without any
 * result-set processing.
 *
 * @author Zdenko Vrabel (zdenko.vrabel@celum.com)
 */
public class SqlExecutionStrategy implements SqlScriptStrategy {

    /** holds open connection to DB */
    private final Connection con;

    /**
     * Constructor
     * @param con
     */
    public SqlExecutionStrategy(Connection con)
    {
        this.con = con;
    }


    /**
     * Method executes the one simple SQL line that ends with ';'.
     * The ';' is removed from statement.
     *
     * @param sql sql line end with ';'
     */
    @Override
    public void query(String sql)
    {
        Statement stmt = null;
        try {
            sql = sql.trim();
            if (sql.endsWith(";")) {
                sql = sql.substring(0, sql.length() -1);
            }

            stmt = con.createStatement();
            stmt.execute(sql);
        } catch (SQLException e) {
            throw new SqlCommandException(sql, e);
        } finally {
            DbUtils.closeQuietly(stmt);
        }
    }
}